@@ -20,6 +20,7 @@
 #include "../misc/network.h"
 #include "../misc/pcap_openvas.h" /* for v6_is_local_ip */
 #include "../misc/plugutils.h"    /* for plug_get_host_fqdn */
+#include "base/hosts.h"
 #include "nasl_debug.h"
 #include "nasl_func.h"
 #include "nasl_global_ctxt.h"
@@ -234,6 +235,58 @@ get_host_open_port (lex_ctxt *lexic)
   return retc;
 }
 
+/**
+ * @brief implements ip_reverse_lookup
+ *
+ */
+
+tree_cell *
+host_reverse_lookup (lex_ctxt *lexic)
+{
+  char *t = get_str_var_by_num (lexic, 0);
+  gvm_host_t *target = NULL;
+  tree_cell *retc;
+
+  if (t == NULL)
+    {
+      t = plug_get_host_ip_str (lexic->script_infos);
+    }
+  else
+    {
+      // we need to duplicate t because plug_get_host_ip_from_str allocates
+      // memory and to have the same behavior for both we simply duplicate the
+      // memory here
+      t = g_strdup (t);
+    }
+  if (t == NULL)
+    {
+      nasl_perror (lexic, "Empty target\n");
+      goto fail;
+    }
+  target = gvm_host_from_str (t);
+  if (target == NULL)
+    {
+      nasl_perror (lexic, "%s: Invalid target\n", t);
+      g_free (t);
+      goto fail;
+    }
+  g_free (t);
+
+  t = gvm_host_reverse_lookup (target);
+  if (t == NULL)
+    {
+      goto fail;
+    }
+
+  retc = alloc_typed_cell (CONST_STR);
+  retc->x.str_val = t;
+  retc->size = strlen (t);
+
+  return retc;
+fail:
+  return FAKE_CELL;
+}
+
 tree_cell *
 get_port_state (lex_ctxt *lexic)
 {
