@@ -6,13 +6,15 @@
 
 use std::fs::File;
 
+use crate::nasl::syntax::grammar::{Atom, Expr, Statement};
 use crate::nasl::syntax::{AsBufReader, Loader};
-use crate::nasl::syntax::{IdentifierType, Statement, StatementKind, TokenCategory};
 
 use crate::feed::{
     update,
     verify::{self, HashSumFileItem},
 };
+use crate::nasl::Code;
+
 /// Updates runs nasl plugin with description true and uses given storage to store the descriptive
 /// information
 pub struct Oid<L, V> {
@@ -39,29 +41,25 @@ where
     }
 
     fn script_oid(stmt: &Statement) -> Option<String> {
-        match stmt.kind() {
-            StatementKind::Call(param) => match stmt.start().category() {
-                TokenCategory::Identifier(IdentifierType::Undefined(s)) => match s as &str {
-                    // maybe switch from children to patternmatching?
-                    "script_oid" => param.children().first().map(|x| x.to_string()),
-                    _ => None,
-                },
-                _ => None,
-            },
-            _ => None,
+        if let Statement::ExprStmt(Expr::Atom(Atom::FnCall(call))) = stmt
+            && call.fn_name.to_str() == "script_oid"
+        {
+            return call.args.items.first().map(|x| x.to_string());
         }
+        None
     }
 
     /// Returns the OID string or update::Error::MissingExit.
     fn single(&self, key: String) -> Result<String, update::ErrorKind> {
-        let code = self.loader.load(key.as_ref())?;
-        for stmt in crate::nasl::syntax::parse(&code) {
-            if let StatementKind::If(_, stmts, _, _) = stmt?.kind() {
-                if let StatementKind::Block(x) = stmts.kind() {
-                    for stmt in x {
-                        if let Some(oid) = Self::script_oid(stmt) {
-                            return Ok(oid);
-                        }
+        for stmt in Code::load(&self.loader, &key)?
+            .parse()
+            .result()
+            .map_err(update::ErrorKind::SyntaxError)?
+        {
+            if let Statement::If(if_) = stmt {
+                for stmt in &if_.if_branches[0].1.items {
+                    if let Some(oid) = Self::script_oid(stmt) {
+                        return Ok(oid);
                     }
                 }
             }
