@@ -7,7 +7,7 @@ use thiserror::Error;
 // use crate::nasl::utils::combine_function_sets;
 use crate::nasl::prelude::*;
 
-use crate::nasl::utils::{ContextType, IntoFunctionSet, Register, StoredFunctionSet};
+use crate::nasl::utils::{IntoFunctionSet, Register, StoredFunctionSet};
 
 pub mod aes_cbc;
 pub mod aes_ccm;
@@ -19,9 +19,11 @@ pub mod bf_cbc;
 pub mod des;
 pub mod hash;
 pub mod hmac;
+pub mod misc;
 pub mod pem_to;
 pub mod rc4;
 pub mod rsa;
+pub mod smb;
 
 #[cfg(test)]
 mod tests;
@@ -40,6 +42,8 @@ pub enum CryptographicError {
     Rsa(String),
     #[error("Error in RC4: {0}.")]
     Rc4(String),
+    #[error("Error in SMB: {0}.")]
+    Smb(String),
 }
 
 enum Crypt {
@@ -55,13 +59,13 @@ fn get_required_named_data<'a>(
     register: &'a Register,
     key: &'a str,
 ) -> Result<&'a [u8], ArgumentError> {
-    match register.named(key) {
-        Some(ContextType::Value(NaslValue::Data(x))) => Ok(x.as_slice()),
-        Some(ContextType::Value(NaslValue::String(x))) => Ok(x.as_bytes()),
-        Some(x) => Err(ArgumentError::wrong_argument(
+    match register.nasl_value(key) {
+        Ok(NaslValue::Data(x)) => Ok(x.as_slice()),
+        Ok(NaslValue::String(x)) => Ok(x.as_bytes()),
+        Ok(x) => Err(ArgumentError::wrong_argument(
             key,
             "a String or Data Value",
-            format!("{:?}", x).as_str(),
+            format!("{x:?}").as_str(),
         )),
         _ => Err(ArgumentError::MissingNamed(vec![key.into()])),
     }
@@ -72,12 +76,12 @@ fn get_required_named_data<'a>(
 /// set to Some value. If it is false, no error will be returned but the Option can be either Some
 /// or None.
 fn get_optional_named_number(register: &Register, key: &str) -> Result<Option<i64>, ArgumentError> {
-    match register.named(key) {
-        Some(ContextType::Value(NaslValue::Number(x))) => Ok(Some(*x)),
-        Some(x) => Err(ArgumentError::wrong_argument(
+    match register.nasl_value(key) {
+        Ok(NaslValue::Number(x)) => Ok(Some(*x)),
+        Ok(x) => Err(ArgumentError::wrong_argument(
             key,
             "a Number Value",
-            format!("{:?}", x).as_str(),
+            format!("{x:?}").as_str(),
         )),
         _ => Ok(None),
     }
@@ -139,6 +143,8 @@ impl IntoFunctionSet for Cryptographic {
         set.add_set(rsa::Rsa);
         set.add_set(bf_cbc::BfCbc);
         set.add_set(pem_to::PemTo);
+        set.add_set(smb::Smb);
+        set.add_set(misc::Misc);
         set
     }
 }
