@@ -20,7 +20,7 @@ pub struct CipherHandler {
 
 fn lock_handlers(
     handlers: &Arc<Mutex<Vec<CipherHandler>>>,
-) -> Result<MutexGuard<Vec<CipherHandler>>, FnError> {
+) -> Result<MutexGuard<'_, Vec<CipherHandler>>, FnError> {
     // we actually need to panic as a lock error is fatal
     // alternatively we need to add a poison error on FnError
     Ok(Arc::as_ref(handlers).lock().unwrap())
@@ -58,8 +58,8 @@ impl CipherHandlers {
     /// Closes a stream cipher.
     #[nasl_function]
     pub fn close_stream_cipher(&self, register: &Register) -> Result<NaslValue, FnError> {
-        let hd = match register.named("hd") {
-            Some(ContextType::Value(NaslValue::Number(x))) => *x as i32,
+        let hd = match register.nasl_value("hd") {
+            Ok(NaslValue::Number(x)) => *x as i32,
             _ => return Err(CryptographicError::Rc4("Handler ID not found".to_string()).into()),
         };
 
@@ -69,7 +69,7 @@ impl CipherHandlers {
                 handlers.remove(i);
                 Ok(NaslValue::Number(0))
             }
-            _ => Err(CryptographicError::Rc4(format!("Handler ID {} not found", hd)).into()),
+            _ => Err(CryptographicError::Rc4(format!("Handler ID {hd} not found")).into()),
         }
     }
 
@@ -116,19 +116,19 @@ impl CipherHandlers {
             _ => return Err(CryptographicError::Rc4("Missing data argument".to_string()).into()),
         };
 
-        let hd = match register.named("hd") {
-            Some(ContextType::Value(NaslValue::Number(x))) => *x as i32,
+        let hd = match register.nasl_value("hd") {
+            Ok(NaslValue::Number(x)) => *x as i32,
             _ => 0,
         };
 
         let mut handlers = lock_handlers(&self.cipher_handlers)?;
 
-        if hd > 0 {
-            if let Some((_i, h)) = handlers.iter_mut().enumerate().find(|(_i, h)| h.id == hd) {
-                let d = h.handler.encode(data);
-                return Ok(NaslValue::Data(d));
-            };
-        };
+        if hd > 0
+            && let Some((_i, h)) = handlers.iter_mut().enumerate().find(|(_i, h)| h.id == hd)
+        {
+            let d = h.handler.encode(data);
+            return Ok(NaslValue::Data(d));
+        }
 
         let key = match get_key(register) {
             Ok(k) if !k.is_empty() => k.to_vec(),
