@@ -7,10 +7,7 @@ mod tests;
 
 use thiserror::Error;
 
-use crate::function_set;
-use crate::nasl::syntax::NaslValue;
-use crate::nasl::utils::Context;
-use crate::nasl::utils::error::FnError;
+use crate::nasl::prelude::*;
 use crate::storage::items::kb::KbKey;
 use nasl_function_proc_macro::nasl_function;
 
@@ -26,7 +23,7 @@ pub enum KBError {
 /// Only pushes unique values for the given name.
 #[nasl_function(named(name, value, expires))]
 fn set_kb_item(
-    c: &Context,
+    c: &ScanCtx,
     name: NaslValue,
     value: NaslValue,
     expires: Option<u64>,
@@ -37,7 +34,7 @@ fn set_kb_item(
 
 /// NASL function to get a knowledge base
 #[nasl_function]
-fn get_kb_item(c: &Context, key: &str) -> Result<NaslValue, FnError> {
+fn get_kb_item(c: &ScanCtx, key: &str) -> Result<NaslValue, FnError> {
     let kbs = c.get_kb_item(&KbKey::Custom(key.to_string()))?;
     let ret = NaslValue::Fork(kbs.into_iter().map(NaslValue::from).collect());
 
@@ -46,13 +43,13 @@ fn get_kb_item(c: &Context, key: &str) -> Result<NaslValue, FnError> {
 
 /// NASL function to replace a kb list
 #[nasl_function(named(name, value))]
-fn replace_kb_item(c: &Context, name: NaslValue, value: NaslValue) -> Result<(), FnError> {
+fn replace_kb_item(c: &ScanCtx, name: NaslValue, value: NaslValue) -> Result<(), FnError> {
     c.set_single_kb_item(KbKey::Custom(name.to_string()), value.as_kb())
 }
 
 /// NASL function to retrieve an item in a KB.
 #[nasl_function]
-fn get_kb_list(c: &Context, key: &str) -> Result<NaslValue, FnError> {
+fn get_kb_list(c: &ScanCtx, key: &str) -> Result<NaslValue, FnError> {
     let kbs = c.get_kb_item(&KbKey::Custom(key.to_string()))?;
     let ret = NaslValue::Array(kbs.into_iter().map(NaslValue::from).collect());
 
