@@ -107,10 +107,31 @@ fn unixtime() -> Result<u64, MiscError> {
         .map_err(|e| MiscError::TimeBefore1970(e.to_string()))
 }
 
+fn to_bytes(value: NaslValue) -> Vec<u8> {
+    match value {
+        NaslValue::String(x) => x.into(),
+        NaslValue::Data(x) => x,
+        NaslValue::Array(x) => x
+            .iter()
+            .flat_map(<&NaslValue as Into<Vec<u8>>>::into)
+            .collect(),
+        NaslValue::Boolean(_) | NaslValue::Number(_) | NaslValue::Dict(_) => {
+            value.to_string().as_bytes().into()
+        }
+        NaslValue::AttackCategory(_)
+        | NaslValue::Fork(_)
+        | NaslValue::Null
+        | NaslValue::Return(_)
+        | NaslValue::Continue
+        | NaslValue::Break
+        | NaslValue::Exit(_) => vec![],
+    }
+}
+
 /// Compress given data with gzip, when headformat is set to 'gzip' it uses gzipheader.
 #[nasl_function(named(data, headformat))]
 fn gzip(data: NaslValue, headformat: Option<&str>) -> Option<Vec<u8>> {
-    let data = Vec::<u8>::from(data);
+    let data = to_bytes(data);
     let headformat = headformat.unwrap_or("noheaderformat");
     if headformat.eq_ignore_ascii_case("gzip") {
         let mut e = GzEncoder::new(Vec::new(), Compression::default());
@@ -124,7 +145,7 @@ fn gzip(data: NaslValue, headformat: Option<&str>) -> Option<Vec<u8>> {
 /// uncompress given data with gzip, when headformat is set to 'gzip' it uses gzipheader.
 #[nasl_function(named(data))]
 fn gunzip(data: NaslValue) -> Option<String> {
-    let data = Vec::<u8>::from(data);
+    let data = to_bytes(data);
     let mut uncompress = ZlibDecoder::new(&data[..]);
     let mut uncompressed = String::new();
     match uncompress.read_to_string(&mut uncompressed) {
@@ -218,13 +239,10 @@ fn localtime(secs: Option<i64>, utc: Option<NaslValue>) -> HashMap<String, NaslV
 /// This argument must be a string everything else will return False per default.
 /// Returns NaslValue::Boolean(true) when defined NaslValue::Boolean(false) otherwise.
 #[nasl_function]
-fn defined_func(ctx: &Context, register: &Register, fn_name: Option<Maybe<&str>>) -> bool {
+fn defined_func(ctx: &ScanCtx, register: &Register, fn_name: Option<Maybe<&str>>) -> bool {
     fn_name
         .and_then(Maybe::as_option)
-        .map(|fn_name| match register.named(fn_name) {
-            Some(ContextType::Function(_, _)) => true,
-            _ => ctx.nasl_fn_defined(fn_name),
-        })
+        .map(|fn_name| register.function_exists(fn_name) || ctx.nasl_fn_defined(fn_name))
         .unwrap_or(false)
 }
 
@@ -247,7 +265,20 @@ fn gettimeofday() -> Result<String, MiscError> {
 /// nor returns any arguments.
 #[nasl_function]
 fn dump_ctxt(register: &Register) {
-    register.dump(register.index() - 1);
+    register.dump();
+}
+
+/// Is a debug function to print the keys available within the called context. It does not take any
+/// nor returns any arguments.
+#[nasl_function]
+fn vendor_version(context: &ScanCtx<'_>) -> Result<NaslValue, MiscError> {
+    match context
+        .scan_preferences
+        .get_preference_string("vendor_version")
+    {
+        Some(v) => Ok(NaslValue::String(v)),
+        None => Ok(NaslValue::Null),
+    }
 }
 
 pub struct Misc;
@@ -270,5 +301,6 @@ function_set! {
         defined_func,
         gettimeofday,
         dump_ctxt,
+        vendor_version,
     )
 }
