@@ -43,14 +43,11 @@ impl Write for UdpConnection {
     fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
         let mtu = mtu(self.socket.peer_addr()?.ip());
         if buf.len() > mtu {
-            return Err(io::Error::new(
-                io::ErrorKind::Other,
-                format!(
-                    "UDP data of size {} exceeds the maximum length of {}",
-                    buf.len(),
-                    mtu
-                ),
-            ));
+            return Err(io::Error::other(format!(
+                "UDP data of size {} exceeds the maximum length of {}",
+                buf.len(),
+                mtu
+            )));
         }
         let result = unsafe {
             libc::send(
@@ -88,8 +85,8 @@ impl UdpConnection {
     pub fn new_priv(addr: IpAddr, sport: u16, dport: u16) -> io::Result<Self> {
         let sock_addr = SocketAddr::new(addr, sport);
         let socket = match sock_addr {
-            SocketAddr::V4(_) => UdpSocket::bind(format!("0.0.0.0:{}", sport)),
-            SocketAddr::V6(_) => UdpSocket::bind(format!("[::]:{}", sport)),
+            SocketAddr::V4(_) => UdpSocket::bind(format!("0.0.0.0:{sport}")),
+            SocketAddr::V6(_) => UdpSocket::bind(format!("[::]:{sport}")),
         }?;
         socket.connect(SocketAddr::new(addr, dport))?;
         socket.set_read_timeout(Some(Duration::from_secs(1)))?;
