@@ -15,3 +15,5 @@ pub const FC_ANON_ARGS: &str = "_FCT_ANON_ARGS";
 /// In the current state of the rust implementation (2023-01-23) we don't have the interface to store data between different script runs.
 // Therefore it is currently stored within the register with this key.
 pub const TARGET: &str = "_OPENVAS_TARGET";
+/// _SCRIPT_PARAMS is used to gather script parameters within a function call
+pub const SCRIPT_PARAMS: &str = "_SCRIPT_PARAMS";
