@@ -5,8 +5,7 @@
 use crate::models::{Product, ProductsAdvisories};
 use crate::nasl::syntax::{FSPluginLoader, Loader};
 
-use crate::feed::check_signature;
-use crate::feed::{HashSumNameLoader, SignatureChecker, VerifyError};
+use crate::feed::{HashSumNameLoader, SignatureChecker, VerifyError, check_signature};
 use crate::notus::error::{Error, LoadProductErrorKind};
 
 use super::{AdvisoryLoader, FeedStamp, ProductLoader};
@@ -67,15 +66,15 @@ impl ProductLoader for HashsumProductLoader {
     }
 
     fn has_changed(&self, os: &str, stamp: &FeedStamp) -> bool {
-        if let Ok(mut loader) = HashSumNameLoader::sha256(&self.loader) {
-            if let Some(Ok(file_item)) = loader.find(|entry| {
+        if let Ok(mut loader) = HashSumNameLoader::sha256(&self.loader)
+            && let Some(Ok(file_item)) = loader.find(|entry| {
                 if let Ok(item) = entry {
                     return item.get_filename() == format!("{os}.notus");
                 }
                 false
-            }) {
-                return *stamp != FeedStamp::Hashsum(file_item.get_hashsum());
-            }
+            })
+        {
+            return *stamp != FeedStamp::Hashsum(file_item.get_hashsum());
         }
         false
     }
