@@ -2,7 +2,10 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
+use scannerlib::models::PreferenceValue;
+use scannerlib::scanner::preferences::preference::{PREFERENCES, ScanPrefValue};
 use std::{
+    collections::HashMap,
     fmt::{self, Display, Formatter},
     net::SocketAddr,
     path::PathBuf,
@@ -58,6 +61,8 @@ pub struct Scanner {
     pub scanner_type: ScannerType,
     #[serde(default)]
     pub ospd: OspdWrapper,
+    #[serde(default)]
+    pub preferences: HashMap<String, ScanPrefValue>,
 }
 
 #[derive(Deserialize, Serialize, Debug, Clone)]
@@ -317,17 +322,32 @@ impl Display for Config {
 }
 
 impl Config {
+    fn read_to_string<P>(path: P) -> String
+    where
+        P: AsRef<std::path::Path> + std::fmt::Display + std::fmt::Debug,
+    {
+        std::fs::read_to_string(&path)
+            .unwrap_or_else(|e| panic!("Failed to read openvasd config from file: {path:?}. {e}"))
+    }
+
     fn load_etc() -> Option<Self> {
-        let config = std::fs::read_to_string("/etc/openvasd/openvasd.toml").unwrap_or_default();
-        toml::from_str(&config).ok()
+        let path = "/etc/openvasd/openvasd.toml";
+        if !std::fs::exists(path).unwrap_or_default() {
+            return None;
+        }
+        let config = Self::read_to_string(path);
+        toml::from_str(&config).unwrap()
     }
 
     fn load_user() -> Option<Self> {
         match std::env::var("HOME") {
             Ok(home) => {
-                let path = format!("{}/.config/openvasd/openvasd.toml", home);
-                let config = std::fs::read_to_string(path).unwrap_or_default();
-                toml::from_str(&config).ok()
+                let path = format!("{home}/.config/openvasd/openvasd.toml");
+                if !std::fs::exists(&path).unwrap_or_default() {
+                    return None;
+                }
+                let config = Self::read_to_string(path);
+                toml::from_str(&config).unwrap()
             }
             Err(_) => None,
         }
@@ -337,13 +357,26 @@ impl Config {
     where
         P: AsRef<std::path::Path> + std::fmt::Display + std::fmt::Debug,
     {
-        let config = std::fs::read_to_string(&path)
-            .unwrap_or_else(|e| panic!("Failed to read openvasd config from file: {path:?}. {e}"));
+        let config = std::fs::read_to_string(path).unwrap();
+
         toml::from_str(&config).unwrap()
     }
 
+    fn ret_pref_value_or_panic_with_wrong_type(
+        p: &ScanPrefValue,
+        expected: &str,
+        name: &str,
+    ) -> ScanPrefValue {
+        match (p, expected) {
+            (ScanPrefValue::Bool(_), "bool") => p.clone(),
+            (ScanPrefValue::Int(_), "int") => p.clone(),
+            (ScanPrefValue::String(_), "string") => p.clone(),
+            _ => panic!("Wrong value type. Expected {expected} for {name}"),
+        }
+    }
+
     pub fn load() -> Self {
-        let cmds = clap::Command::new("openvasd")
+        let mut cmds = clap::Command::new("openvasd")
             .arg(
                 clap::Arg::new("config")
                     .short('c')
@@ -553,8 +586,19 @@ impl Config {
                     .value_name("service,service_notus")
                     .value_parser(Mode::Service)
                     .help("Sets the openvasd mode"),
-            )
-            .get_matches();
+            );
+
+        for pref in PREFERENCES {
+            let mut arg = clap::Arg::new(pref.id).long(pref.id).help(pref.description);
+            arg = match pref.default {
+                PreferenceValue::Bool(_) => arg.value_parser(clap::builder::BoolValueParser::new()),
+                PreferenceValue::String(_) => arg.value_parser(clap::value_parser!(String)),
+                PreferenceValue::Int(_) => arg.value_parser(clap::value_parser!(i64)),
+            };
+            cmds = cmds.arg(arg);
+        }
+
+        let cmds = cmds.get_matches();
         let mut config = match cmds.get_one::<String>("config") {
             Some(path) => Self::from_file(path),
             None => {
@@ -565,6 +609,7 @@ impl Config {
                 }
             }
         };
+
         if let Some(interval) = cmds.get_one::<u64>("feed-check-interval") {
             config.feed.check_interval = Duration::from_secs(*interval);
         }
@@ -635,24 +680,70 @@ impl Config {
         if let Some(mode) = cmds.get_one::<Mode>("mode") {
             config.mode = mode.clone();
         }
-        if let Some(key) = cmds.get_one::<String>("storage_key") {
-            if !key.is_empty() {
-                config.storage.fs.key = Some(key.clone());
-            }
+        if let Some(key) = cmds.get_one::<String>("storage_key")
+            && !key.is_empty()
+        {
+            config.storage.fs.key = Some(key.clone());
         }
+
+        let scan_prefs: HashMap<String, ScanPrefValue> = PREFERENCES
+            .iter()
+            .map(|pref| {
+                let val = match pref.default {
+                    PreferenceValue::Bool(_) => {
+                        if let Some(p) = cmds.get_one::<bool>(pref.id) {
+                            ScanPrefValue::Bool(*p)
+                        } else if let Some(p) = config.scanner.preferences.get(pref.id) {
+                            Self::ret_pref_value_or_panic_with_wrong_type(p, "bool", pref.id)
+                        } else {
+                            pref.default.clone().into()
+                        }
+                    }
+                    PreferenceValue::String(_) => {
+                        if let Some(p) = cmds.get_one::<String>(pref.id) {
+                            ScanPrefValue::String(p.to_string())
+                        } else if let Some(p) = config.scanner.preferences.get(pref.id) {
+                            Self::ret_pref_value_or_panic_with_wrong_type(p, "string", pref.id)
+                        } else {
+                            pref.default.clone().into()
+                        }
+                    }
+                    PreferenceValue::Int(_) => {
+                        if let Some(p) = cmds.get_one::<i64>(pref.id) {
+                            ScanPrefValue::Int(*p)
+                        } else if let Some(p) = config.scanner.preferences.get(pref.id) {
+                            Self::ret_pref_value_or_panic_with_wrong_type(p, "int", pref.id)
+                        } else {
+                            pref.default.clone().into()
+                        }
+                    }
+                };
+                (pref.id.to_string(), val)
+            })
+            .collect();
+
+        config.scanner.preferences = scan_prefs;
         config
     }
 }
 
 #[cfg(test)]
 mod tests {
-    use std::{path::PathBuf, time::Duration};
-
     use crate::config::StorageType;
+    use scannerlib::scanner::preferences::preference::ScanPrefValue;
+    use std::{path::PathBuf, time::Duration};
 
     #[test]
     fn defaults() {
-        let config = super::Config::default();
+        let mut config = super::Config::default();
+        config
+            .scanner
+            .preferences
+            .insert("aaa".to_string(), ScanPrefValue::Bool(false));
+        config.scanner.preferences.insert(
+            "bbb".to_string(),
+            ScanPrefValue::String("foobar".to_string()),
+        );
 
         assert_eq!(
             config.feed.path,
