@@ -8,6 +8,7 @@ pub mod feed;
 pub mod results;
 
 use std::{
+    fmt::Display,
     net::SocketAddr,
     sync::{Arc, RwLock},
 };
@@ -34,6 +35,21 @@ where
     }
 }
 
+impl Display for ClientHash {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(
+            f,
+            "{}",
+            self.0
+                .iter()
+                .fold(String::with_capacity(self.0.len() * 2), |mut a, x| {
+                    a.push_str(&format!("{x:02x}"));
+                    a
+                })
+        )
+    }
+}
+
 /// Contains information about an authorization model of a connection (e.g. mtls)
 #[derive(Default, Debug, Clone)]
 pub enum ClientIdentifier {
