@@ -6,9 +6,9 @@ use std::fmt::Display;
 use std::sync::Arc;
 use std::time::SystemTime;
 
-use crate::storage::{Error as StorageError, FeedHash, Storage};
+use crate::storage::{Error as StorageError, FeedHash, MappedID, Storage};
 use async_trait::async_trait;
-use scannerlib::models::scanner::Error as ScanError;
+use scannerlib::models::scanner::{Error as ScanError, ScanResultKind};
 use scannerlib::models::scanner::{ScanResultFetcher, ScanResults, ScanStopper};
 use scannerlib::models::{Phase, Scan, Status};
 use scannerlib::storage::items::nvt::Nvt;
@@ -47,8 +47,8 @@ impl Display for Error {
             Error::ScanAlreadyQueued => write!(f, "scan is already queued"),
             Error::NotFound => write!(f, "scan was not found"),
             Error::QueueFull => write!(f, "unable to queue scan: queue is already full"),
-            Error::Scan(e) => write!(f, "scan error occurred: {}", e),
-            Error::Storage(e) => write!(f, "storage error occurred: {}", e),
+            Error::Scan(e) => write!(f, "scan error occurred: {e}"),
+            Error::Storage(e) => write!(f, "storage error occurred: {e}"),
             Error::UnsupportedResume => {
                 write!(f, "unable to resume scan: operation not supported")
             }
@@ -77,7 +77,7 @@ impl From<StorageError> for Error {
 // yo, dawg I heard you like transforming
 impl From<Error> for ScanError {
     fn from(val: Error) -> Self {
-        ScanError::Unexpected(format!("{}", val))
+        ScanError::Unexpected(format!("{val}"))
     }
 }
 /// Scheduler is a core component of managing scans.
@@ -94,9 +94,11 @@ impl From<Error> for ScanError {
 #[derive(Debug)]
 pub struct Scheduler<DB, Scanner> {
     /// Contains the currently queued scan ids.
+    //TODO: remove queued in favor of a function within the storage to get scans that are stored
     queued: RwLock<Vec<String>>,
 
     /// Contains the currently running scan ids.
+    //TODO: remove running in favor of a function within the storage to get scans that are requested
     running: RwLock<Vec<String>>,
     /// Is used to retrieve scans and update status.
     db: DB,
@@ -155,14 +157,15 @@ where
         }
 
         let mut queued = self.queued.write().await;
-        if let Some(max_queuing) = self.config().max_queued_scans {
-            if queued.len() == max_queuing {
-                return Err(Error::QueueFull);
-            }
+        if let Some(max_queuing) = self.config().max_queued_scans
+            && queued.len() == max_queuing
+        {
+            return Err(Error::QueueFull);
         }
         if queued.iter().any(|x| x == id) {
             return Err(Error::ScanAlreadyQueued);
         }
+        //TODO: update_status should not be done this way,
         self.update_status(id, status).await?;
         queued.push(id.to_string());
         Ok(())
@@ -184,12 +187,13 @@ where
         }
 
         self.db.remove_scan(id).await?;
-        // TODO change from I to &str so that we don't have to clone everywhere
-        self.db.remove_scan_id(id.to_string()).await?;
+        //TODO: why not in remove_scan?
+        self.db.remove_mapped_id(id).await?;
+
         Ok(())
     }
 
-    /// Coordinates scan starts, if a feed syncrhonization is taking place it will do nothing.
+    /// Coordinates scan starts, if a feed synchronization is taking place it will do nothing.
     /// Otherwise it start scans within the capacity block from queued list.
     async fn coordinate_scans(&self) -> Result<(), Error> {
         if *self.is_synchronizing_feed.read().await {
@@ -198,6 +202,7 @@ where
         }
         let config = self.config();
         let mut queued = self.queued.write().await;
+        // TODO: add function to storage to count running scans
         let mut running = self.running.write().await;
         let amount_to_start = if let Some(mrs) = config.max_running_scans {
             mrs - running.len()
@@ -256,12 +261,14 @@ where
             match self.fetch_results(scan_id.clone()).await {
                 // using self.append_fetch_result instead of db to keep track of the status
                 // and may remove them from running.
-                Ok(mut results) => {
-                    if self.scanner.do_addition() {
-                        let scan_status = self.db.get_status(&scan_id).await?;
-                        results.status.update_with(&scan_status);
-                    }
-                    match self.append_fetched_result(vec![results]).await {
+                Ok(results) => {
+                    match self
+                        .append_fetched_result(
+                            self.scanner.scan_result_status_kind(),
+                            vec![results],
+                        )
+                        .await
+                    {
                         Ok(()) => {
                             tracing::trace!(%scan_id, "fetched and append results");
                         }
@@ -349,42 +356,35 @@ where
     }
 }
 
+//TODO: why are we doing this?
 #[async_trait]
 impl<DB, S> ScanIDClientMapper for Scheduler<DB, S>
 where
     DB: Storage + Sync + Send + 'static,
     S: Send + Sync,
 {
-    async fn add_scan_client_id(
+    async fn generate_mapped_id(
         &self,
+        client: ClientHash,
         scan_id: String,
-        client_id: ClientHash,
-    ) -> Result<(), StorageError> {
-        self.db.add_scan_client_id(scan_id, client_id).await
+    ) -> Result<MappedID, crate::storage::Error> {
+        self.db.generate_mapped_id(client, scan_id).await
     }
-    async fn remove_scan_id<I>(&self, scan_id: I) -> Result<(), StorageError>
-    where
-        I: AsRef<str> + Send + 'static,
-    {
-        self.db.remove_scan_id(scan_id).await
-    }
-
-    async fn get_scans_of_client_id(
+    async fn list_mapped_scan_ids(
         &self,
-        client_id: &ClientHash,
-    ) -> Result<Vec<String>, StorageError> {
-        self.db.get_scans_of_client_id(client_id).await
+        client: &ClientHash,
+    ) -> Result<Vec<String>, crate::storage::Error> {
+        self.db.list_mapped_scan_ids(client).await
     }
-
-    async fn is_client_allowed<I>(
+    async fn get_mapped_id(
         &self,
-        scan_id: I,
-        client_id: &ClientHash,
-    ) -> Result<bool, StorageError>
-    where
-        I: AsRef<str> + Send + 'static,
-    {
-        self.db.is_client_allowed(scan_id, client_id).await
+        client: &ClientHash,
+        scan_id: &str,
+    ) -> Result<MappedID, crate::storage::Error> {
+        self.db.get_mapped_id(client, scan_id).await
+    }
+    async fn remove_mapped_id(&self, id: &str) -> Result<(), crate::storage::Error> {
+        self.db.remove_mapped_id(id).await
     }
 }
 
@@ -504,7 +504,12 @@ where
     DB: Storage + Sync + Send + 'static,
     S: Sync + Send,
 {
-    async fn append_fetched_result(&self, results: Vec<ScanResults>) -> Result<(), StorageError> {
+    async fn append_fetched_result(
+        &self,
+        kind: ScanResultKind,
+        results: Vec<ScanResults>,
+    ) -> Result<(), StorageError> {
+        //TODO: will be done in the storage instead, this is annoying
         let mut running = self.running.write().await;
         for x in results.iter() {
             match x.status.status {
@@ -519,7 +524,7 @@ where
         drop(running);
 
         tracing::trace!("appending results");
-        self.db.append_fetched_result(results).await
+        self.db.append_fetched_result(kind, results).await
     }
 }
 
