@@ -15,7 +15,10 @@ use std::{
 
 use async_trait::async_trait;
 use scannerlib::{
-    models::{self, FeedType, Scan, Status, VulnerabilityData, scanner::ScanResults},
+    models::{
+        self, FeedType, Scan, Status, VulnerabilityData,
+        scanner::{ScanResultKind, ScanResults},
+    },
     storage::{Dispatcher, error::StorageError, inmemory::InMemoryStorage, items::nvt::Nvt},
 };
 
@@ -87,29 +90,18 @@ impl From<StorageError> for Error {
     }
 }
 
+pub type MappedID = String;
+
 #[async_trait]
 pub trait ScanIDClientMapper {
-    async fn add_scan_client_id(&self, scan_id: String, client_id: ClientHash)
-    -> Result<(), Error>;
-    async fn remove_scan_id<I>(&self, scan_id: I) -> Result<(), Error>
-    where
-        I: AsRef<str> + Send + 'static;
-
-    async fn get_scans_of_client_id(&self, client_id: &ClientHash) -> Result<Vec<String>, Error>;
-
-    async fn is_client_allowed<I>(&self, scan_id: I, client_id: &ClientHash) -> Result<bool, Error>
-    where
-        I: AsRef<str> + Send + 'static,
-    {
-        let scans = self.get_scans_of_client_id(client_id).await?;
-        let sid = scan_id.as_ref();
-        for id in scans {
-            if id == sid {
-                return Ok(true);
-            }
-        }
-        Ok(false)
-    }
+    async fn generate_mapped_id(
+        &self,
+        client: ClientHash,
+        scan_id: String,
+    ) -> Result<MappedID, Error>;
+    async fn list_mapped_scan_ids(&self, client: &ClientHash) -> Result<Vec<String>, Error>;
+    async fn get_mapped_id(&self, client: &ClientHash, scan_id: &str) -> Result<MappedID, Error>;
+    async fn remove_mapped_id(&self, id: &str) -> Result<(), Error>;
 }
 
 #[async_trait]
@@ -223,15 +215,25 @@ pub trait ScanStorer {
 ///
 /// This is used when a scan is started and the results are fetched from ospd.
 pub trait AppendFetchResult {
-    async fn append_fetched_result(&self, results: Vec<ScanResults>) -> Result<(), Error>;
+    async fn append_fetched_result(
+        &self,
+        kind: ScanResultKind,
+        results: Vec<ScanResults>,
+    ) -> Result<(), Error>;
 }
 #[async_trait]
 impl<T> AppendFetchResult for Arc<T>
 where
     T: AppendFetchResult + Send + Sync,
 {
-    async fn append_fetched_result(&self, results: Vec<ScanResults>) -> Result<(), Error> {
-        self.as_ref().append_fetched_result(results).await
+    async fn append_fetched_result(
+        &self,
+
+        kind: ScanResultKind,
+
+        results: Vec<ScanResults>,
+    ) -> Result<(), Error> {
+        self.as_ref().append_fetched_result(kind, results).await
     }
 }
 
@@ -318,29 +320,21 @@ impl<T> ScanIDClientMapper for Arc<T>
 where
     T: ScanIDClientMapper + Send + Sync,
 {
-    async fn add_scan_client_id(
+    async fn generate_mapped_id(
         &self,
+        client: ClientHash,
         scan_id: String,
-        client_id: ClientHash,
-    ) -> Result<(), Error> {
-        self.as_ref().add_scan_client_id(scan_id, client_id).await
+    ) -> Result<MappedID, Error> {
+        self.as_ref().generate_mapped_id(client, scan_id).await
     }
-    async fn remove_scan_id<I>(&self, scan_id: I) -> Result<(), Error>
-    where
-        I: AsRef<str> + Send + 'static,
-    {
-        self.as_ref().remove_scan_id(scan_id).await
+    async fn list_mapped_scan_ids(&self, client: &ClientHash) -> Result<Vec<String>, Error> {
+        self.as_ref().list_mapped_scan_ids(client).await
     }
-
-    async fn get_scans_of_client_id(&self, client_id: &ClientHash) -> Result<Vec<String>, Error> {
-        self.as_ref().get_scans_of_client_id(client_id).await
+    async fn get_mapped_id(&self, client: &ClientHash, scan_id: &str) -> Result<MappedID, Error> {
+        self.as_ref().get_mapped_id(client, scan_id).await
     }
-
-    async fn is_client_allowed<I>(&self, scan_id: I, client_id: &ClientHash) -> Result<bool, Error>
-    where
-        I: AsRef<str> + Send + 'static,
-    {
-        self.as_ref().is_client_allowed(scan_id, client_id).await
+    async fn remove_mapped_id(&self, id: &str) -> Result<(), Error> {
+        self.as_ref().remove_mapped_id(id).await
     }
 }
 
