@@ -240,7 +240,7 @@ pub fn tls_config(config: &crate::config::Config) -> Result<Option<TlsConfig>, E
 }
 
 fn error(err: String) -> io::Error {
-    io::Error::new(io::ErrorKind::Other, err)
+    io::Error::other(err)
 }
 
 // Load public certificate from file.
@@ -249,8 +249,8 @@ where
     P: AsRef<Path> + std::fmt::Debug,
 {
     // Open certificate file.
-    let certfile = fs::File::open(filename)
-        .map_err(|e| error(format!("failed to open {:?}: {}", filename, e)))?;
+    let certfile =
+        fs::File::open(filename).map_err(|e| error(format!("failed to open {filename:?}: {e}")))?;
     let mut reader = io::BufReader::new(certfile);
     rustls_pemfile_old::certs(&mut reader)
         .map(|x| x.into_iter().map(CertificateDer::from).collect())
@@ -262,8 +262,8 @@ where
     P: AsRef<Path> + std::fmt::Debug,
 {
     // Open keyfile.
-    let keyfile = fs::File::open(filename)
-        .map_err(|e| error(format!("failed to open {:?}: {}", filename, e)))?;
+    let keyfile =
+        fs::File::open(filename).map_err(|e| error(format!("failed to open {filename:?}: {e}")))?;
     let mut reader = io::BufReader::new(keyfile);
 
     loop {
