@@ -368,18 +368,24 @@ pub struct ScanResult {
 
 impl From<&ScanResult> for crate::models::ResultType {
     fn from(sr: &ScanResult) -> Self {
-        match (sr.name.as_str(), &sr.result_type) {
-            ("HOST_START", ResultType::Log) => crate::models::ResultType::HostStart,
-            ("HOST_END", ResultType::Log) => crate::models::ResultType::HostEnd,
-            ("DEADHOST", ResultType::Log) => crate::models::ResultType::DeadHost,
-            ("Host Details", ResultType::Log) => crate::models::ResultType::HostDetail,
-            (_, ResultType::Log) => crate::models::ResultType::Log,
-            (_, ResultType::Alarm) => crate::models::ResultType::Alarm,
-            (_, ResultType::Error) => crate::models::ResultType::Error,
-            (_, ResultType::HostStart) => crate::models::ResultType::HostStart,
-            (_, ResultType::HostEnd) => crate::models::ResultType::HostEnd,
+        match (
+            sr.port.clone().unwrap_or("".to_string()).as_str(),
+            sr.name.as_str(),
+            &sr.result_type,
+        ) {
+            // Not only the Host Details script produces host details. Therefore, check the port
+            ("general/Host_Details", _, ResultType::Log) => crate::models::ResultType::HostDetail,
+            (_, "HOST_START", ResultType::Log) => crate::models::ResultType::HostStart,
+            (_, "HOST_END", ResultType::Log) => crate::models::ResultType::HostEnd,
+            (_, "DEADHOST", ResultType::Log) => crate::models::ResultType::DeadHost,
+            (_, "Host Details", ResultType::Log) => crate::models::ResultType::HostDetail,
+            (_, _, ResultType::Log) => crate::models::ResultType::Log,
+            (_, _, ResultType::Alarm) => crate::models::ResultType::Alarm,
+            (_, _, ResultType::Error) => crate::models::ResultType::Error,
+            (_, _, ResultType::HostStart) => crate::models::ResultType::HostStart,
+            (_, _, ResultType::HostEnd) => crate::models::ResultType::HostEnd,
             // host details are sent via log messages
-            (_, ResultType::HostDetail) => unreachable!(),
+            (_, _, ResultType::HostDetail) => unreachable!(),
         }
     }
 }
@@ -728,7 +734,7 @@ mod tests {
                     panic!("no scan");
                 }
             }
-            _ => panic!("wrong type: {:?}", response),
+            _ => panic!("wrong type: {response:?}"),
         }
     }
 
@@ -759,7 +765,7 @@ mod tests {
                     panic!("no scan");
                 }
             }
-            _ => panic!("wrong type: {:?}", response),
+            _ => panic!("wrong type: {response:?}"),
         }
     }
 
@@ -783,9 +789,7 @@ mod tests {
                    port="443/tcp"
                    test_id=""
                    name="Path disclosure vulnerability"
-                   type="Log Message">
-             bla
-           </result>
+                   type="Log Message">bla</result>
          </results>
          <progress>
             <host name="127.0.0.1">45</host>
@@ -828,7 +832,7 @@ mod tests {
                     panic!("no scan");
                 }
             }
-            _ => panic!("wrong type: {:?}", response),
+            _ => panic!("wrong type: {response:?}"),
         }
     }
 
