@@ -8,10 +8,11 @@ use std::path::{Path, PathBuf};
 use feed::VerifyError;
 use quick_xml::DeError;
 use scannerlib::nasl::WithErrorInfo;
-use scannerlib::nasl::{interpreter::InterpretError, syntax::LoadError};
+use scannerlib::nasl::syntax::ParseError;
+use scannerlib::nasl::{interpreter::InterpreterError, syntax::LoadError};
+use scannerlib::scanner::ExecuteError;
 use scannerlib::storage::error::StorageError;
 use scannerlib::{feed, notus};
-use scannerlib::{nasl::syntax::SyntaxError, scanner::ExecuteError};
 
 #[derive(Debug, thiserror::Error)]
 
@@ -22,7 +23,7 @@ pub enum CliErrorKind {
         err_msg: String,
     },
     #[error("{0}")]
-    InterpretError(InterpretError),
+    InterpretError(InterpreterError),
     #[error("{0}")]
     ExecuteError(#[from] ExecuteError),
     #[error("{0}")]
@@ -31,12 +32,15 @@ pub enum CliErrorKind {
     LoadError(LoadError),
     #[error("{0}")]
     StorageError(StorageError),
-    #[error("{0}")]
-    SyntaxError(SyntaxError),
+    // TODO fix this error message.
+    #[error("Encountered syntax errors.")]
+    SyntaxError(Vec<ParseError>),
     #[error("{0}")]
     Corrupt(String),
     #[error("Invalid XML: {0}")]
     InvalidXML(#[from] DeError),
+    #[error("{0}")]
+    InvalidCmdOpt(String),
 }
 
 pub struct Filename<T>(pub T);
@@ -93,7 +97,7 @@ impl fmt::Display for CliError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "{}", self.kind)?;
         if let Some(filename) = &self.filename {
-            write!(f, " filename: {:?}", filename)?;
+            write!(f, " filename: {filename:?}")?;
         }
         Ok(())
     }
@@ -156,8 +160,8 @@ impl From<LoadError> for CliErrorKind {
     }
 }
 
-impl From<InterpretError> for CliErrorKind {
-    fn from(value: InterpretError) -> Self {
+impl From<InterpreterError> for CliErrorKind {
+    fn from(value: InterpreterError) -> Self {
         Self::InterpretError(value)
     }
 }
@@ -168,12 +172,6 @@ impl From<StorageError> for CliErrorKind {
     }
 }
 
-impl From<SyntaxError> for CliErrorKind {
-    fn from(value: SyntaxError) -> Self {
-        Self::SyntaxError(value)
-    }
-}
-
 impl From<LoadError> for CliError {
     fn from(value: LoadError) -> Self {
         Self {
